# mypy-boto3-cognito-idp

Type annotations for
[boto3.CognitoIdentityProvider 1.10.50](https://boto3.amazonaws.com/v1/documentation/api/1.10.50/reference/services/cognito-idp.html#CognitoIdentityProvider) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

More information can be found [here](https://vemel.github.io/mypy_boto3/).

- [mypy-boto3-cognito-idp](#mypy-boto3-cognito-idp)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
    - [Code auto-complete](#code-auto-complete)
  - [How it works](#how-it-works)

## How to use

### Type checking

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `CognitoIdentityProvider` service.

```bash
python -m pip install boto3-stubs[mypy-boto3-cognito-idp]
```

Use `boto3` with `mypy_boto3` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3 import cognito_idp
# alternative import if you do not want to install mypy_boto3 package
# import mypy_boto3_cognito_idp as cognito_idp

# Use this client as usual, now mypy can check if your code is valid.
# Check if your IDE supports function overloads,
# you probably do not need explicit type annotations
# client = boto3.client("cognito-idp")
client: cognito_idp.CognitoIdentityProviderClient = boto3.client("cognito-idp")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: cognito_idp.CognitoIdentityProviderClient = session.client("cognito-idp")


# Paginators need type annotation on creation
admin_list_groups_for_user_paginator: cognito_idp.AdminListGroupsForUserPaginator = client.get_paginator("admin_list_groups_for_user")
admin_list_user_auth_events_paginator: cognito_idp.AdminListUserAuthEventsPaginator = client.get_paginator("admin_list_user_auth_events")
list_groups_paginator: cognito_idp.ListGroupsPaginator = client.get_paginator("list_groups")
list_identity_providers_paginator: cognito_idp.ListIdentityProvidersPaginator = client.get_paginator("list_identity_providers")
list_resource_servers_paginator: cognito_idp.ListResourceServersPaginator = client.get_paginator("list_resource_servers")
list_user_pool_clients_paginator: cognito_idp.ListUserPoolClientsPaginator = client.get_paginator("list_user_pool_clients")
list_user_pools_paginator: cognito_idp.ListUserPoolsPaginator = client.get_paginator("list_user_pools")
list_users_paginator: cognito_idp.ListUsersPaginator = client.get_paginator("list_users")
list_users_in_group_paginator: cognito_idp.ListUsersInGroupPaginator = client.get_paginator("list_users_in_group")
```

## How it works

Fully automated [builder](https://github.com/vemel/mypy_boto3) carefully generates
type annotations for each service, patiently waiting for `boto3` updates. It delivers
a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type annotations
  extracted from the documentation (blame `botocore` docs if types are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) for readability.